@@ -6,6 +6,7 @@
 # @Software: PyCharm
 
 from zeo_utils.zeo_base import ZeoBase
+from zeo_utils.prop_parser import PropParser
 
 
 class Network(ZeoBase):
@@ -21,17 +22,20 @@ class Network(ZeoBase):
         """
         print(self._get_command_res(self._network_exec_fp))
 
-    def calc_pore_diameter(self, cif_fp: str) -> str:
+    def calc_pore_diameter(self, cif_fp: str, need_log: bool = False) -> {}:
         """ 计算孔径
 
         原理是调用命令   ./network.exe -ha -res ***.cif
 
         :param cif_fp: cif文件的路径，相对路径或绝对路径都行
+        :param need_log:
         """
         cif_fp = self._get_abs_path(cif_fp)
-        return self._get_command_res(f"{self._network_exec_fp} -ha -res {cif_fp}")
+        pdm = self._get_command_res(f"{self._network_exec_fp} -ha -res {cif_fp}")
+        return PropParser.parse(pdm, need_log=need_log)
 
-    def calc_specific_surface_area(self, cif_fp: str, chan_radius: float, probe_radius: float, num_samples: int) -> str:
+    def calc_specific_surface_area(self, cif_fp: str, chan_radius: float, probe_radius: float, num_samples: int,
+                                   need_log: bool = False) -> {}:
         """ 计算比表面积
 
         原理是调用命令  ./network.exe -ha -sa chen_radius probe_radius num_sample ***.cif
@@ -40,13 +44,15 @@ class Network(ZeoBase):
         :param chan_radius: 用于探测材料内孔道空间可及性情况的探针分子半径（Å）
         :param probe_radius: 用于计算比表面积的探针分子半径（Å）
         :param num_samples: 在每个材料原子周围进行Monte Carlo抽样探测的次数
+        :param need_log:
         """
         cif_fp = self._get_abs_path(cif_fp)
-        return self._get_command_res(
-            f"{self._network_exec_fp} -ha -sa {chan_radius} {probe_radius} {num_samples} {cif_fp}")
+        ssa = self._get_command_res(f"{self._network_exec_fp} -ha -sa {chan_radius} {probe_radius} "
+                                    f"{num_samples} {cif_fp}")
+        return PropParser.parse(ssa, need_log=need_log)
 
     def calc_accessible_volume(self, cif_fp: str, chan_radius: float, probe_radius: float,
-                               num_samples: int):
+                               num_samples: int, need_log: bool = False) -> {}:
         """ 计算可及孔体积
 
                原理是调用命令  ./network.exe -ha -vol chen_radius probe_radius num_sample ***.cif
@@ -55,12 +61,15 @@ class Network(ZeoBase):
                :param chan_radius: 用于探测材料内孔道空间可及性情况的探针分子半径（Å）
                :param probe_radius: 用于计算比表面积的探针分子半径（Å）
                :param num_samples: 在每个材料原子周围进行Monte Carlo抽样探测的次数
+               :param need_log:
                """
         cif_fp = self._get_abs_path(cif_fp)
-        return self._get_command_res(f"{self._network_exec_fp} -ha -vol {chan_radius} {probe_radius} {num_samples} "
-                                     f"{cif_fp}")
+        av = self._get_command_res(f"{self._network_exec_fp} -ha -vol {chan_radius} {probe_radius} {num_samples} "
+                                   f"{cif_fp}")
+        return PropParser.parse(av, need_log=need_log)
 
-    def calc_pore_size_distribution(self, cif_fp: str, chan_radius: float, probe_radius: float, num_samples: int):
+    def calc_pore_size_distribution(self, cif_fp: str, chan_radius: float, probe_radius: float, num_samples: int,
+                                    need_log: bool = False) -> {}:
         """ 计算孔径分布
 
         原理是调用命令  ./network.exe -ha -psd chen_radius probe_radius num_sample ***.cif
@@ -69,11 +78,14 @@ class Network(ZeoBase):
         :param chan_radius: 用于探测材料内孔道空间可及性情况的探针分子半径（Å）
         :param probe_radius: 用于计算比表面积的探针分子半径（Å）
         :param num_samples: 在每个材料原子周围进行Monte Carlo抽样探测的次数
+        :param need_log:
         """
         cif_fp = self._get_abs_path(cif_fp)
-        return self._get_command_res(
-            f"{self._network_exec_fp} -ha -psd {chan_radius} {probe_radius} {num_samples} {cif_fp}")
+        psd = self._get_command_res(f"{self._network_exec_fp} -ha -psd {chan_radius} {probe_radius} "
+                                    f"{num_samples} {cif_fp}")
+        return PropParser.parse(psd, need_log=need_log)
 
 
 if __name__ == "__main__":
+    print(Network('../example/network.exe').test())
     pass
